Documentation
¶
Overview ¶
Package signer contains signing helpers used to compute the CouchDB proxy authentication token.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Signer ¶
type Signer struct {
// contains filtered or unexported fields
}
Signer computes deterministic HMAC tags using a static secret. It is used to produce CouchDB proxy authentication tokens for securing the communication between the proxy and CouchDB.
Click to show internal directories.
Click to hide internal directories.